use leptos::prelude::*;

pub struct HeaderItems {
    pub left: Vec<HeaderItem>,
    pub middle: Vec<HeaderItem>,
    pub right: Vec<HeaderItem>,
}

pub struct HeaderItem {
    pub text: String,
    pub link: Option<String>,
}

#[component]
pub fn Header(items: HeaderItems) -> impl IntoView {
    let HeaderItems { left, middle, right } = items;

    view! {
        <div class="text-xl font-semibold p-4 flex gap-4">
            // Left side of header
            <Items items=left />

            // Expanding space in the middle
            <div class="flex-auto mx-auto">
                <Items items=middle />
            </div>

            // Right side of header
            <Items items=right />
        </div>
    }
}

#[component]
fn Items(items: Vec<HeaderItem>) -> impl IntoView {
    items.into_iter().map(|item| view! { <Item item /> }).collect_view()
}

#[component]
fn Item(item: HeaderItem) -> impl IntoView {
    let text = item.text;
    let link = item.link;

    if let Some(link) = link {
        view! {
            <a href=link>
                <span class="whitespace-nowrap">{text}</span>
            </a>
        }
        .into_any()
    } else {
        view! { <span class="whitespace-nowrap">{text}</span> }.into_any()
    }
}
